<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>LinetypeSettings</name>
    <message>
        <location filename="../LinetypeSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translation>Prednastavené pre Nové výkresy</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Linetype</source>
        <translation>Typ linkovania</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Global Linetype Scale:</source>
        <translation>Celková mierka linkovania:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Scale of linetypes matches the scale of each viewport</source>
        <translation>Mierka typov čiar zodpovedá mierke každého výrezu</translation>
    </message>
</context>
</TS>
